@@ -1,6 +1,13 @@
 from .attachments import Attachment, Color, Field
-from .blocks import ActionsBlock, ContextBlock, DividerBlock, FileBlock, ImageBlock, SectionBlock,\
-    HeaderBlock
+from .blocks import (
+    ActionsBlock,
+    ContextBlock,
+    DividerBlock,
+    FileBlock,
+    ImageBlock,
+    SectionBlock,
+    HeaderBlock,
+)
 from .elements import Button, Confirm, Element, Image, Text, TextType
 from .messages import MessageResponse, Message
 from .modals import Modal
